
#line 3 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else  /* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif  /* defined (__STDC__) */
#endif  /* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
  do \
    { \
    /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
    *yy_cp = (yy_hold_char); \
    YY_RESTORE_YY_MORE_OFFSET \
    (yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
    YY_DO_BEFORE_ACTION; /* set up yytext again */ \
    } \
  while ( 0 )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
  {
  FILE *yy_input_file;

  char *yy_ch_buf;    /* input buffer */
  char *yy_buf_pos;    /* current position in input buffer */

  /* Size of input buffer in bytes, not including room for EOB
   * characters.
   */
  yy_size_t yy_buf_size;

  /* Number of characters read into yy_ch_buf, not including EOB
   * characters.
   */
  size_t yy_n_chars;

  /* Whether we "own" the buffer - i.e., we know we created it,
   * and can realloc() it to grow it, and should free() it to
   * delete it.
   */
  int yy_is_our_buffer;

  /* Whether this is an "interactive" input source; if so, and
   * if we're using stdio for input, then we want to use getc()
   * instead of fread(), to make sure we stop fetching input after
   * each newline.
   */
  int yy_is_interactive;

  /* Whether we're considered to be at the beginning of a line.
   * If so, '^' rules will be active on the next match, otherwise
   * not.
   */
  int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
  /* Whether to try to fill the input buffer when we reach the
   * end of it.
   */
  int yy_fill_buffer;

  int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
  /* When an EOF's been seen but there's still some text to process
   * then we mark the buffer as YY_EOF_PENDING, to indicate that we
   * shouldn't try reading from the input source any more.  We might
   * still have a bunch of tokens to match, though, because of
   * possible backing-up.
   *
   * When we actually see the EOF, we change the status to "new"
   * (via yyrestart()), so that the user can continue scanning by
   * just pointing yyin at a new input file.
   */
#define YY_BUFFER_EOF_PENDING 2

  };
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static size_t yy_n_chars;    /* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;    /* whether we need to initialize */
static int yy_start = 0;  /* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
  { \
  if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
    YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
  } \
  YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
  }

#define yy_set_bol(at_bol) \
  { \
  if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
    YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
  } \
  YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
  }

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
  (yytext_ptr) = yy_bp; \
  yyleng = (size_t) (yy_cp - yy_bp); \
  (yy_hold_char) = *yy_cp; \
  *yy_cp = '\0'; \
  (yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 94
#define YY_END_OF_BUFFER 95
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
  {
  flex_int32_t yy_verify;
  flex_int32_t yy_nxt;
  };
static yyconst flex_int16_t yy_accept[772] =
    {   0,
        0,    0,   95,   93,   89,   89,   93,   92,   93,   84,
       88,   88,   90,   91,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   89,    9,    9,   93,
       93,    0,    1,   11,   84,    0,    0,   88,   88,   88,
        0,    0,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   88,   88,   88,
       88,   88,   88,    0,    9,    0,    0,   86,   10,   85,
       11,    0,   88,    0,    0,   14,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   30,   88,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   88,   87,   10,   10,

       10,   10,    0,   88,   88,   88,   37,   36,   88,   88,
       88,   88,   88,    0,   88,   88,   33,   88,   88,   88,
       88,   88,   88,   88,   88,   88,   35,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   10,
       10,   10,   10,   10,   10,    0,   88,   88,   88,   88,
       26,   39,   88,   31,   88,    0,    0,   88,   88,    0,
       88,   88,   88,   88,   88,   88,   32,   88,   88,   88,
       88,    0,    0,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   10,   10,   10,   10,   10,
       10,   10,    0,   88,   88,   88,   88,    0,   34,   42,

        0,    0,   88,   88,    0,    0,   88,   88,   88,   88,
       88,   27,    0,   88,   88,   43,   88,   88,    0,    0,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   10,   10,   10,   10,   10,   10,   10,   10,
        2,    0,   88,   88,   12,   24,    0,    0,    0,    0,
       20,   88,    0,    0,   18,   88,   88,   28,   88,    0,
       88,    0,   88,   88,   38,    0,    0,    0,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   10,   10,
       10,   10,   10,   10,   10,   12,   88,   88,    0,   20,

        0,    0,   88,   19,   18,    0,   21,   40,   88,    0,
       17,    0,   88,   41,    0,    0,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       10,   10,   10,    3,   10,   10,   88,   88,    0,    0,
       19,   88,   21,    0,   88,   29,   17,    0,   88,    0,
        0,   87,   87,   87,   87,   87,   87,   87,   45,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,    3,   10,   10,    3,   10,
       10,   72,   88,    0,    0,   15,    0,   88,    0,   88,

        0,   25,    0,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   12,    3,   10,   10,   10,
       10,   88,    0,   22,    0,   23,   25,    0,   87,   87,
       87,   48,   87,   87,   87,    0,    0,   87,   47,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   74,   87,
       87,   87,   87,   87,   10,   10,   10,   10,   88,   22,
       23,    0,   87,   87,   87,   87,   87,   87,    0,   13,
       87,   87,   87,   87,   87,   46,   87,   76,   78,   80,
       70,   87,   87,   87,   87,   75,   87,   87,   10,   10,

       10,   10,   88,    0,    0,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   77,   79,   81,
       87,   87,   10,   10,   10,   10,   10,   10,   10,   88,
        0,   16,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   82,   83,   87,   87,   87,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   73,   55,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   10,

       10,   10,   10,   10,   10,   10,   10,   10,    8,   87,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   51,
       87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
       87,   10,   10,   10,   10,    8,   10,   10,   10,   10,
        8,   87,   87,   87,   54,   50,   87,   87,   87,   87,
       65,   52,   87,   49,   87,   87,   87,   87,   64,   87,
       87,   87,   10,   10,   10,   10,    8,   10,   10,   10,
       10,   87,   87,   87,   60,   61,   62,   63,   87,   56,
       57,   58,   59,   87,   87,   87,   10,   10,   10,   10,
       10,   10,   10,   10,   87,   87,   87,   87,   87,   87,

       87,   10,   10,   10,   10,    7,   10,   10,   10,   68,
       87,   44,   87,   71,   87,   87,    7,   10,   10,   10,
        7,   10,    5,    6,   87,   87,   87,   87,    7,   10,
        5,    6,   10,    5,    6,   87,   87,   87,   87,   10,
        5,    6,   10,   87,   87,   87,   67,   10,    4,   87,
       87,   87,    4,    4,   87,   87,   87,    4,   87,   87,
       66,   87,   87,   69,   87,   87,   87,   87,   87,   53,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    1,    6,    7,    1,    1,    8,    1,    9,
       10,   11,    1,    8,    8,   12,   13,   14,   15,   16,
       17,   18,   19,   20,   19,   21,   19,   22,   23,    1,
        8,    1,    1,    1,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   31,   33,   34,   35,   36,   37,   38,
       31,   39,   40,   41,   42,   43,   44,   45,   46,   31,
       47,    1,   48,    1,   49,    1,   50,   51,   52,   53,

       54,   55,   56,   57,   58,   59,   60,   61,   62,   63,
       64,   65,   31,   66,   67,   68,   69,   70,   71,   72,
       73,   31,    8,    1,    8,    8,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[74] =
    {   0,
        1,    2,    3,    2,    2,    4,    1,    1,    1,    5,
        1,    1,    1,    6,    7,    7,    7,    7,    7,    7,
        7,    1,    8,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    1,   10,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9
    } ;

static yyconst flex_int16_t yy_base[799] =
    {   0,
        0,   72, 1713, 1714, 1714, 1714,    0, 1714,   67,   72,
     1663,   53,   79, 1714,   67,   47,   48,   49,   54,   51,
       55,   52,   57,   50,   61,   73,  125, 1714, 1714, 1708,
      121, 1704, 1714,    0,  128, 1660,  105, 1659,  107,  103,
      155,  159,  106,  122,   76,  116,  118,   90,  120,  121,
      123,  124,  125,  129,  126,  142,  130,  146,  137,  133,
      147,  148,  149,  212, 1714, 1694, 1703, 1714,  194, 1714,
        0,  156, 1656,  218,  224, 1714,  186,  155,  181,  182,
      183,  184,  159,  162,  185,  241,  191,  187,  188,  189,
      200,  203,  192,  205,  207,  210,  211,  284,  257,    0,

      256, 1663,  225,  242,  230,  226, 1654, 1653,  222,  228,
      231,  232,  235,  301,  246,  236,  327,  238,  268,  272,
      285,  270,  286,  287,  266,  288,  344, 1652,  290,  292,
      250,  301,  248,  295,  302,  293,  303,  309,  332,    0,
      351, 1659,  329, 1645, 1653,  330,  343,  333,  335,  355,
      372, 1648,  337, 1647,  334, 1631, 1637,  331,  341,  393,
      340,  350,  351,  352,  357,  358,  413,  359,  373,  364,
      374,  426,  434,  362,  258,  383,  384,  393,  391,  392,
      395,  400,  401,  397,  408,  428, 1639, 1647, 1667, 1662,
     1622, 1685,  417,  428,  437,  426,  425,  476, 1638, 1637,

     1622, 1620,  420,  421, 1620, 1618,  423,  433,  424,  435,
      434, 1632,  490,  436,  501, 1631,  458,  448,  511,  515,
      449,  459,  451,  489,  462,  479,  517,  487,  485,  484,
      481,  502, 1655, 1650, 1610, 1673, 1640, 1648, 1621, 1669,
     1714,  496,  520,  509, 1622, 1621,  559, 1601, 1612, 1601,
      569,  500, 1598, 1602, 1615,  521,  510, 1614,  526, 1599,
      516,  583,  532,  529, 1612,  588,  592,  600,  557,  534,
      558,  559,  563,  564,  566,  568,  567,  518,  572,  574,
      570,  578,  582,  579,  609,  588,  590,  603, 1625, 1633,
     1606, 1654, 1628, 1614, 1588, 1604,  616, 1603, 1591,  652,

     1582,  657,  600, 1600, 1714, 1592,  665, 1598,  622, 1578,
     1596, 1587,  623, 1594,  674,  682,  631,  614,  639,  640,
      482,  625,  641,  596,  645,  646,  649,  651,  653,  654,
      655,  656,  660,  662,  666,  663,  687,  675,  680,  688,
     1614, 1600, 1574,    0, 1607, 1580,  682,  698,  730, 1573,
     1714,  681,  738,  746,  696, 1587, 1714, 1585,  689,  758,
     1570,  705,  715,  707,  708,  717,  709,  697, 1584,  723,
      724,  726,  728,  729,  730,  731,  732,  736,  735,  742,
      738,  744,  740,  746,  756,    0, 1600, 1573,    0, 1593,
     1564, 1579,  753,  809,  813, 1714, 1564,  770, 1563,  752,

     1559, 1575, 1565,  774,  772,  773,  775,  778,  782,  784,
      829,  786,  788,  791,  792,  793,  795,  797,  800,  846,
      798,  804,  805,  806,  808, 1573,    0, 1584, 1555, 1583,
     1550,  827, 1561, 1567, 1547, 1565, 1714, 1560,  820,  830,
      837, 1563,  828,  831,  832,  879, 1601,  848, 1561,  833,
      836,  843,  840,  844,  842,  874,  886,  885, 1560,  855,
      858,  894,  879,  863, 1572, 1539, 1601, 1547,  888, 1714,
     1714,  928,  868,  869,  872,  873,  878,  928, 1594, 1714,
      891,  889,  898,  915,  935, 1554,  937, 1553, 1552, 1551,
     1550,  900,  936,  910,  942, 1549,  916,  913, 1592, 1538,

      941, 1531,  930,  971,  985,  923,  929,  934,  947,  949,
      958,  965,  966,  967,  954,  957,  961,  968,  963,  970,
      983,  986,  987,  974, 1009, 1008,  978, 1545, 1544, 1543,
      979,  980, 1004, 1527, 1540, 1535, 1534, 1533, 1523,  997,
     1045, 1714,  985,  991,  988, 1004, 1010, 1011, 1014, 1016,
     1018, 1020, 1021, 1024, 1025, 1026, 1031, 1033, 1035, 1039,
     1041, 1536, 1535, 1028, 1037, 1043, 1533, 1528, 1527, 1526,
     1516, 1508, 1510, 1522, 1521, 1552, 1524, 1523, 1059, 1046,
     1047, 1050, 1048, 1052, 1053, 1058, 1060,  990, 1062, 1086,
     1066, 1068, 1069, 1070, 1075, 1074, 1090, 1080, 1081, 1501,

     1503, 1515, 1514, 1545, 1512, 1513, 1559, 1558,    0, 1087,
     1089, 1093, 1092, 1095, 1096, 1097, 1098, 1099, 1102, 1513,
     1103, 1104, 1105, 1106, 1108, 1109, 1111, 1112, 1100, 1121,
     1122, 1507, 1508, 1554, 1553,    0, 1507, 1490, 1531, 1504,
        0, 1129, 1124, 1131, 1497, 1487, 1133, 1134, 1135, 1136,
     1477, 1467, 1137, 1457, 1138, 1139, 1143, 1144, 1447, 1160,
     1142, 1147, 1436, 1410, 1442, 1406,    0, 1368, 1371, 1367,
     1357, 1161, 1162, 1164, 1355, 1351, 1331, 1327, 1165, 1317,
     1313, 1312, 1309, 1166, 1167, 1184, 1289, 1289, 1272, 1271,
     1264, 1262, 1256, 1247, 1172, 1173, 1169, 1175, 1177, 1176,

     1181, 1242, 1243, 1239, 1238,    0, 1235, 1238, 1236, 1249,
     1188, 1248, 1185, 1247, 1193, 1186,    0, 1224, 1198, 1131,
        0, 1131,    0,    0, 1196, 1199, 1214, 1201,    0,  994,
        0,    0,  977,    0,    0, 1202, 1217, 1206, 1204,  907,
        0,    0,  603, 1222, 1210, 1220,  550,  427,    0, 1224,
     1221, 1209,    0,    0, 1227, 1228, 1229,    0, 1215, 1234,
      353, 1235, 1236,  154, 1252, 1239, 1242, 1241, 1246,  127,
     1714, 1310, 1315, 1319, 1327, 1334, 1344, 1353, 1363, 1368,
     1377, 1387, 1396, 1405, 1415, 1424, 1433, 1443, 1453, 1463,
     1473, 1483, 1493, 1503, 1513, 1523, 1533, 1543

    } ;

static yyconst flex_int16_t yy_def[799] =
    {   0,
      771,    1,  771,  771,  771,  771,  772,  771,  771,  773,
      774,  774,  775,  771,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  771,  771,  771,  776,
      771,  772,  771,  777,  773,  773,  773,  774,  774,  774,
      775,  778,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  771,  771,  771,  776,  771,  779,  771,
      777,  773,  774,  771,  778,  771,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  780,  781,  779,

      779,  779,  773,  774,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  771,  774,  774,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  774,  774,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  781,
      781,  781,  779,  779,  779,  773,  774,  774,  774,  774,
      774,  774,  774,  774,  774,  771,  771,  774,  774,  771,
      774,  774,  774,  774,  774,  774,  774,  774,  774,  774,
      774,  771,  771,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  781,  781,  781,  779,  779,
      779,  782,  773,  774,  774,  774,  774,  771,  774,  774,

      771,  771,  774,  774,  771,  771,  774,  774,  774,  774,
      774,  774,  771,  774,  774,  774,  774,  774,  771,  783,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  781,  781,  781,  784,  779,  779,  779,  782,
      771,  773,  774,  774,  774,  774,  771,  771,  771,  771,
      774,  774,  771,  771,  774,  774,  774,  774,  774,  771,
      774,  771,  774,  774,  774,  771,  771,  783,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  781,  781,
      781,  784,  779,  779,  779,  773,  774,  774,  771,  771,

      771,  771,  774,  774,  771,  771,  774,  774,  774,  771,
      774,  771,  774,  774,  771,  771,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      781,  781,  781,  785,  779,  779,  774,  774,  786,  771,
      771,  774,  771,  771,  774,  774,  771,  771,  774,  771,
      771,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  787,  781,  781,  785,  779,
      779,  774,  774,  771,  786,  771,  771,  774,  771,  774,

      771,  774,  771,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  787,  781,  781,  779,
      779,  774,  771,  774,  771,  774,  771,  771,  780,  780,
      780,  780,  780,  780,  780,  771,  788,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  781,  781,  779,  779,  774,  771,
      771,  771,  780,  780,  780,  780,  780,  780,  788,  771,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  781,  781,

      779,  779,  774,  771,  771,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  781,  781,  779,  779,  779,  779,  779,  774,
      771,  771,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  781,  781,  781,  781,
      781,  779,  779,  779,  779,  779,  774,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  781,

      781,  781,  781,  781,  779,  779,  779,  779,  789,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  781,  781,  781,  781,  790,  779,  779,  779,  779,
      789,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  781,  781,  781,  781,  790,  779,  779,  779,
      779,  780,  780,  780,  780,  780,  780,  780,  780,  780,
      780,  780,  780,  780,  780,  780,  781,  781,  781,  781,
      779,  779,  779,  779,  780,  780,  780,  780,  780,  780,

      780,  781,  781,  781,  781,  791,  779,  779,  779,  780,
      780,  780,  780,  780,  780,  780,  792,  781,  781,  781,
      791,  779,  793,  794,  780,  780,  780,  780,  792,  781,
      795,  796,  779,  793,  794,  780,  780,  780,  780,  781,
      795,  796,  779,  780,  780,  780,  780,  781,  797,  780,
      780,  780,  798,  797,  780,  780,  780,  798,  780,  780,
      780,  780,  780,  780,  780,  780,  780,  780,  780,  780,
        0,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771

    } ;

static yyconst flex_int16_t yy_nxt[1788] =
    {   0,
        4,    5,    6,    5,    5,    7,    4,    8,    8,    8,
        8,    8,    9,   10,   10,   10,   10,   10,   10,   10,
       10,    8,    8,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   12,   11,   11,   11,   13,   14,   15,   11,
       16,   17,   18,   11,   19,   11,   11,   20,   11,   11,
       21,   11,   11,   22,   23,   11,   24,   11,   25,   26,
       11,   11,   11,   27,   28,   29,   27,   33,   30,   34,
       41,   41,   41,   41,   31,   35,   35,   35,   35,   35,
       35,   35,   35,   40,   43,   39,   39,   39,   39,   39,

       39,   39,   39,   39,   46,   39,   57,   58,   47,   39,
       45,   48,   49,   52,   50,   44,   54,   59,   53,   51,
       37,   39,   55,   60,   39,   56,   64,   65,   65,   64,
       61,   33,   72,   69,   43,   73,   62,   66,   39,   79,
       63,   35,   35,   35,   35,   35,   35,   35,   35,   43,
       77,   39,   82,   37,   39,   39,   41,   41,   41,   41,
       74,   74,   74,   74,   39,   80,   39,   81,   39,   39,
       39,   39,   39,   39,   39,  139,   37,   39,   39,   78,
       85,   39,   88,   89,   84,   39,   94,   87,   83,   90,
       39,   86,   91,   92,   39,   39,   39,   39,  101,   95,

      103,   93,  139,   39,   37,   97,   76,   39,   98,  111,
       39,  112,   96,   64,   65,   65,   64,  106,  102,   74,
       74,   74,   74,  105,   66,   74,   74,   74,   74,   39,
       39,   39,   39,   39,   39,   39,   39,   39,  113,   39,
       39,  107,  114,  114,  114,  114,  117,  108,   39,  109,
      110,   39,  118,   39,  123,   39,  120,  119,   39,   39,
      121,  141,  146,  127,  125,   76,  149,  143,  122,   43,
       39,   76,  124,   37,   39,  147,   39,  126,   39,   39,
       39,  142,  144,   39,   39,  148,   39,  163,  151,   39,
       39,  153,  159,  150,   39,  152,  139,  155,  139,  154,

      178,  115,  114,  114,  114,  114,  139,  116,  129,  158,
      176,  130,  131,  132,   39,  133,   39,  164,   39,  134,
       39,  170,  222,  135,  136,  165,  137,  138,  160,  160,
      160,  160,  139,   39,   39,   39,   39,  167,  139,  168,
      139,  139,  166,  139,  169,  172,  172,  172,  172,  139,
      139,  139,  173,  174,  177,  180,  171,  139,  179,  185,
      183,  156,  186,  175,  189,  182,  193,  157,  190,  181,
      194,  195,  184,  196,  197,   39,  198,  187,   37,   39,
      139,   39,   39,   39,  161,   39,  200,  162,   39,   39,
      199,   39,   39,  203,  160,  160,  160,  160,   39,   39,

       39,  139,  207,   39,  204,   39,   39,   39,  211,  212,
      139,  215,   39,  208,  213,  213,  213,  213,  209,  210,
       39,   39,   39,  218,  216,  221,  217,  172,  172,  172,
      172,  139,  139,  225,  173,  219,  219,  219,  219,  139,
      139,  139,  246,  139,  220,  139,  223,  228,  139,  139,
      205,  224,  232,  206,  230,  242,  139,  243,  226,  227,
      244,   39,  231,  233,  229,   37,  245,  234,   39,   39,
      214,   39,   39,   39,   39,  251,   39,  247,  247,  247,
      247,   39,   39,   39,   39,   39,  252,  257,  258,  753,
      255,  213,  213,  213,  213,  256,   39,  139,  261,  139,

      271,  259,  262,  262,  262,  262,   39,  139,  265,  269,
      139,  264,  219,  219,  219,  219,  266,  266,  266,  266,
      277,  220,  270,  272,  267,  273,  284,  139,  274,  139,
      139,  275,  139,  139,  276,  139,  296,  139,  285,  288,
      366,  287,  278,  297,   37,  248,  298,  260,   39,   39,
      139,  279,  263,  280,  286,  281,  282,   39,   39,  283,
      247,  247,  247,  247,   39,  139,  139,  304,   39,   39,
      302,  302,  302,  302,   39,  308,  307,   39,  326,  309,
       39,  314,  139,  311,  262,  262,  262,  262,  313,  266,
      266,  266,  266,  315,  315,  315,  315,  267,  139,  318,

      316,  266,  266,  266,  266,  139,  139,  139,  320,  267,
      317,  139,  139,  321,  139,  139,  139,   39,  139,  323,
      139,  327,  139,  329,  328,  319,  139,  139,  248,  303,
      139,  322,  324,  325,  312,  331,  139,  333,  139,  340,
      334,  347,  339,  335,  139,  330,  332,  336,   39,  369,
      337,  139,  338,  302,  302,  302,  302,  139,  302,  302,
      302,  302,  139,  352,   39,  749,  354,  354,  354,  354,
       39,   39,  359,  139,  356,  315,  315,  315,  315,  139,
      362,  363,  316,  360,  360,  360,  360,  139,  139,  139,
      367,  365,  368,  139,  139,  371,  364,  139,  370,  139,

      372,  139,  139,  139,  139,  384,  376,  374,  139,  373,
      139,  139,  350,   39,  139,  380,  381,  350,  382,  375,
      378,  377,  355,  139,  379,  393,  385,  392,  139,   39,
       39,  394,  394,  394,  394,  139,  139,   39,  383,  354,
      354,  354,  354,  398,   39,  139,   39,  354,  354,  354,
      354,  361,  396,  139,  402,  139,  139,  139,  400,  360,
      360,  360,  360,  139,  410,  139,  409,  404,  405,  406,
      408,  139,  139,  407,  139,  411,  139,  139,  139,  139,
      139,  414,  415,  139,  139,  412,  139,  416,  139,  418,
      139,  413,  139,  421,  139,  399,  426,  432,  417,  419,

       39,   39,  420,  399,  139,  424,  423,  422,  439,  425,
      394,  394,  394,  394,  394,  394,  394,  394,   39,  436,
      139,  139,  139,  139,  440,  434,  139,  361,  441,  443,
      139,  396,  139,  446,  139,  396,  139,  447,  442,  139,
      139,  139,  450,  139,  444,  139,  139,  445,  139,  455,
      448,  449,  139,  139,  139,  452,  139,  451,  453,  454,
      456,  461,  457,  460,  105,  458,  459,  469,  139,  473,
      474,  464,  462,  463,  475,   39,  139,  139,  139,  139,
      139,  139,  481,  446,  139,  139,  477,  447,  139,  483,
      139,  139,  139,  488,  139,  476,  139,  478,  484,  486,

      482,  489,  490,  139,  497,  485,  139,  509,  493,  487,
      494,  139,  510,  495,  496,  503,  139,  139,  491,  506,
      139,  139,  139,  517,  492,  529,  139,  139,  498,  504,
      504,  504,  504,  139,  139,  508,   39,  139,  505,  139,
      516,  507,  139,  511,  512,  513,  139,  514,  139,  519,
      520,  521,  522,  525,  523,  528,  526,  527,  139,  530,
      518,  139,  515,  139,  139,  532,  535,  536,  540,  524,
      748,  139,  504,  504,  504,  504,  139,  139,   39,  531,
      537,  505,  139,  139,  139,  139,  541,  541,  543,  541,
      139,  545,  548,  544,  542,  139,  546,  139,  547,  549,

      550,  551,  139,  552,  557,  139,  139,  538,  553,  139,
      554,  139,  556,  139,  139,  139,  139,  558,  139,  555,
      559,  560,  139,  561,  562,  563,  139,  139,  139,  567,
      568,  139,  577,  139,  139,  139,  139,  566,  139,  139,
      743,  564,  565,  569,  579,   39,  541,  541,  578,  541,
      580,  740,  139,  620,  542,  581,  139,  139,  139,  139,
      583,  582,  139,  584,  139,  585,  139,  586,  139,  139,
      570,  587,  139,  139,  139,  589,  139,  591,  590,  139,
      592,  139,  593,  139,  594,  139,  588,  139,  595,  139,
      597,  139,  596,  610,  139,  139,  139,  611,  139,  615,

      139,  139,  598,  616,  617,  599,  139,  139,  139,  618,
      139,  622,  613,  612,  139,  614,  139,  139,  139,  624,
      625,  626,  139,  139,  629,  619,  627,  621,  139,  139,
      631,  623,  630,  644,  139,  139,  642,  139,  139,  628,
      139,  139,  643,  139,  139,  139,  139,  139,  139,  660,
      139,  139,  139,  139,  139,  645,  139,  139,  646,  139,
      139,  647,  648,  649,  650,  651,  652,  653,  654,  139,
      139,  655,  139,  656,  657,  659,  658,  139,  661,  139,
      672,  139,  139,  139,  139,  139,  139,  139,  733,  662,
      139,  139,  139,  673,  732,  139,  675,  676,  677,  678,

      686,  680,  681,  674,  685,  679,  682,  683,  139,  139,
      139,  684,  139,  139,  139,  139,  700,  139,  701,  696,
      139,  139,  712,  139,  139,  139,  695,  698,  697,  139,
      716,  699,  139,  139,  139,  710,  139,  728,  726,  711,
      714,  139,  713,  715,  139,  725,  727,  139,  738,  139,
      139,  737,  139,  745,  139,  746,  750,  139,  139,  736,
      751,  731,  139,  139,  744,  139,  739,  747,  139,  139,
      139,  752,  139,  755,  757,  139,  139,  139,  759,  756,
      762,  760,  139,  139,  139,  763,  766,  139,  767,  139,
      139,  730,  761,  768,  139,  139,  139,  139,  764,  724,

      139,  723,  722,  765,  720,  719,  769,  718,  717,  770,
       32,   32,   32,  709,   32,   32,   32,   32,   32,   32,
       36,   36,  708,   36,   38,   38,  707,   38,   42,   42,
      706,  705,  704,   42,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   71,   71,  703,   71,   71,   71,
       71,   71,   71,   71,   75,   75,  702,  139,   75,   75,
      139,  139,   75,  100,  100,  139,  100,  100,  100,  100,
      100,  100,  100,  128,  128,  139,  128,  140,  140,  139,
      140,  140,  140,  140,  140,  140,  140,  240,  240,  240,
      240,  240,  240,  240,  240,  240,  240,  268,  268,  139,

      268,  268,  268,  139,  268,  292,  292,  292,  292,  292,
      292,  292,  292,  292,  292,  389,  389,  694,  389,  389,
      389,  389,  389,  389,  389,  395,  395,  693,  692,  395,
      395,  395,  395,  427,  427,  691,  427,  427,  427,  427,
      427,  427,  427,  479,  479,  479,  479,  479,  479,  479,
      479,  479,  479,  641,  641,  690,  641,  641,  641,  641,
      641,  641,  641,  667,  667,  689,  667,  667,  667,  667,
      667,  667,  667,  721,  721,  688,  721,  721,  721,  721,
      721,  721,  721,  729,  729,  687,  729,  729,  729,  729,
      729,  729,  729,  734,  734,  139,  734,  734,  734,  734,

      734,  734,  734,  735,  735,  139,  735,  735,  735,  735,
      735,  735,  735,  741,  741,  139,  741,  741,  741,  741,
      741,  741,  741,  742,  742,  139,  742,  742,  742,  742,
      742,  742,  742,  754,  754,  139,  754,  754,  754,  754,
      754,  754,  754,  758,  758,  139,  758,  758,  758,  758,
      758,  758,  758,  671,  670,  669,  668,  666,  665,  664,
      663,  139,  640,  639,  638,  637,  636,  635,  634,  633,
      632,  139,   39,  609,  608,  607,  606,  605,  604,  603,
      602,  601,  600,  139,  139,  576,  575,  574,  573,  572,
      571,  139,  139,  139,  539,  534,  533,  139,  139,  139,

      139,  139,  139,  480,  502,  501,  500,  499,  139,  139,
      480,  139,  472,   39,  471,   39,  470,  468,  467,  466,
      465,  139,  438,   39,  437,  435,  433,   39,  431,  430,
      429,  428,  139,  403,  401,   39,  397,  391,  390,  388,
      387,  386,   39,  358,   39,  357,   39,  353,   39,  351,
      349,  348,   37,  346,  345,  344,  241,  343,  342,  341,
       39,  310,   39,   39,  306,  305,  301,  300,  299,   39,
       39,  241,  295,  294,  293,  241,  291,  290,  289,   39,
       39,  254,  253,  250,  249,   39,   39,  241,  239,  238,
      237,  236,  235,  202,  201,   39,   39,  192,  191,  188,

      139,   39,   39,  145,  104,   68,   99,   39,   37,   70,
       68,   39,  771,    3,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771
    } ;

static yyconst flex_int16_t yy_chk[1788] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    2,    2,    2,    9,    2,    9,
       13,   13,   13,   13,    2,   10,   10,   10,   10,   10,
       10,   10,   10,   12,   15,   16,   17,   18,   24,   20,

       22,   12,   19,   21,   17,   23,   24,   24,   17,   25,
       16,   17,   18,   20,   19,   15,   22,   24,   21,   19,
       10,   26,   23,   25,   45,   23,   27,   27,   27,   27,
       26,   31,   37,   31,   39,   40,   26,   27,   48,   45,
       26,   35,   35,   35,   35,   35,   35,   35,   35,   44,
       43,   40,   48,   37,   43,   39,   41,   41,   41,   41,
       42,   42,   42,   42,   46,   46,   47,   47,   49,   50,
       44,   51,   52,   53,   55,  770,   35,   54,   57,   44,
       51,   60,   54,   55,   50,   59,   59,   53,   49,   55,
       56,   52,   56,   57,   58,   61,   62,   63,   69,   60,

       72,   58,  764,   78,   72,   62,   42,   83,   63,   83,
       84,   84,   61,   64,   64,   64,   64,   78,   69,   74,
       74,   74,   74,   77,   64,   75,   75,   75,   75,   79,
       80,   81,   82,   85,   77,   88,   89,   90,   85,   87,
       93,   79,   86,   86,   86,   86,   87,   80,   91,   81,
       82,   92,   88,   94,   93,   95,   90,   89,   96,   97,
       91,   99,  103,   97,   95,   74,  105,  101,   92,  104,
      109,   75,   94,  103,  106,  104,  110,   96,  105,  111,
      112,   99,  101,  113,  116,  104,  118,  118,  109,   86,
      104,  111,  116,  106,  115,  110,  133,  113,  131,  112,

      133,   86,  114,  114,  114,  114,  175,   86,   98,  115,
      131,   98,   98,   98,  125,   98,  119,  119,  122,   98,
      120,  125,  175,   98,   98,  120,   98,   98,  117,  117,
      117,  117,   98,  121,  123,  124,  126,  122,  129,  123,
      130,  136,  121,  134,  124,  127,  127,  127,  127,  132,
      135,  137,  127,  129,  132,  135,  126,  138,  134,  139,
      137,  114,  141,  130,  143,  136,  146,  114,  143,  135,
      147,  148,  138,  149,  150,  117,  151,  141,  146,  158,
      139,  148,  155,  149,  117,  153,  155,  117,  161,  159,
      153,  147,  127,  158,  160,  160,  160,  160,  162,  163,

      164,  761,  161,  150,  159,  165,  166,  168,  165,  166,
      174,  168,  170,  162,  167,  167,  167,  167,  163,  164,
      151,  169,  171,  171,  169,  174,  170,  172,  172,  172,
      172,  176,  177,  178,  172,  173,  173,  173,  173,  179,
      180,  178,  197,  181,  173,  184,  176,  181,  182,  183,
      160,  177,  185,  160,  183,  193,  185,  194,  179,  180,
      195,  167,  184,  186,  182,  193,  196,  186,  203,  204,
      167,  207,  209,  197,  196,  203,  194,  198,  198,  198,
      198,  208,  211,  210,  214,  195,  204,  209,  210,  748,
      207,  213,  213,  213,  213,  208,  218,  221,  214,  223,

      223,  211,  215,  215,  215,  215,  217,  222,  218,  221,
      225,  217,  219,  219,  219,  219,  220,  220,  220,  220,
      226,  219,  222,  224,  220,  224,  228,  226,  224,  231,
      321,  224,  230,  229,  225,  228,  242,  224,  229,  232,
      321,  231,  227,  243,  242,  198,  244,  213,  252,  215,
      232,  227,  215,  227,  230,  227,  227,  244,  257,  227,
      247,  247,  247,  247,  261,  227,  278,  252,  243,  256,
      251,  251,  251,  251,  259,  257,  256,  264,  278,  259,
      263,  264,  270,  261,  262,  262,  262,  262,  263,  266,
      266,  266,  266,  267,  267,  267,  267,  266,  747,  270,

      267,  268,  268,  268,  268,  269,  271,  272,  272,  268,
      269,  273,  274,  273,  275,  277,  276,  251,  281,  275,
      279,  279,  280,  281,  280,  271,  282,  284,  247,  251,
      283,  274,  276,  277,  262,  283,  286,  285,  287,  288,
      285,  297,  287,  285,  324,  282,  284,  285,  303,  324,
      285,  288,  286,  300,  300,  300,  300,  285,  302,  302,
      302,  302,  318,  303,  297,  743,  307,  307,  307,  307,
      309,  313,  313,  322,  309,  315,  315,  315,  315,  317,
      317,  318,  315,  316,  316,  316,  316,  319,  320,  323,
      322,  320,  323,  325,  326,  326,  319,  327,  325,  328,

      327,  329,  330,  331,  332,  339,  331,  329,  333,  328,
      334,  336,  300,  307,  335,  335,  336,  302,  337,  330,
      333,  332,  307,  338,  334,  348,  340,  347,  339,  352,
      347,  349,  349,  349,  349,  337,  340,  359,  338,  353,
      353,  353,  353,  352,  355,  368,  348,  354,  354,  354,
      354,  316,  349,  362,  359,  364,  365,  367,  355,  360,
      360,  360,  360,  363,  368,  366,  367,  362,  363,  364,
      366,  370,  371,  365,  372,  370,  373,  374,  375,  376,
      377,  373,  374,  379,  378,  371,  381,  375,  383,  377,
      380,  372,  382,  380,  384,  353,  385,  393,  376,  378,

      400,  393,  379,  354,  385,  383,  382,  381,  404,  384,
      394,  394,  394,  394,  395,  395,  395,  395,  398,  400,
      405,  406,  404,  407,  405,  398,  408,  360,  406,  408,
      409,  394,  410,  411,  412,  395,  413,  411,  407,  414,
      415,  416,  414,  417,  409,  418,  421,  410,  419,  419,
      412,  413,  422,  423,  424,  416,  425,  415,  417,  418,
      420,  422,  420,  421,  432,  420,  420,  432,  439,  439,
      440,  425,  423,  424,  441,  432,  443,  411,  440,  444,
      445,  450,  448,  446,  451,  441,  444,  446,  453,  451,
      455,  452,  454,  456,  420,  443,  448,  445,  452,  454,

      450,  457,  458,  460,  463,  453,  461,  476,  462,  455,
      462,  464,  477,  462,  462,  469,  473,  474,  460,  473,
      475,  476,  456,  482,  461,  494,  477,  463,  464,  472,
      472,  472,  472,  458,  457,  475,  469,  482,  472,  481,
      481,  474,  462,  478,  478,  478,  483,  478,  492,  484,
      485,  485,  485,  487,  485,  493,  487,  492,  494,  495,
      483,  498,  478,  484,  497,  498,  501,  501,  503,  485,
      740,  506,  504,  504,  504,  504,  478,  507,  503,  497,
      501,  504,  508,  485,  493,  487,  505,  505,  506,  505,
      495,  508,  511,  507,  505,  509,  509,  510,  510,  512,

      513,  514,  515,  515,  520,  516,  511,  501,  516,  517,
      517,  519,  519,  512,  513,  514,  518,  521,  520,  518,
      522,  523,  524,  524,  525,  526,  527,  531,  532,  533,
      533,  521,  540,  543,  522,  523,  545,  532,  588,  544,
      733,  527,  531,  533,  544,  540,  541,  541,  543,  541,
      545,  730,  546,  588,  541,  546,  526,  525,  547,  548,
      548,  547,  549,  549,  550,  550,  551,  551,  552,  553,
      533,  552,  554,  555,  556,  554,  564,  556,  555,  557,
      557,  558,  558,  559,  559,  565,  553,  560,  560,  561,
      564,  566,  561,  579,  580,  581,  583,  579,  582,  583,

      584,  585,  565,  584,  585,  566,  586,  579,  587,  586,
      589,  590,  581,  580,  591,  582,  592,  593,  594,  592,
      593,  594,  596,  595,  597,  587,  595,  589,  598,  599,
      599,  591,  598,  612,  590,  610,  610,  611,  597,  596,
      613,  612,  611,  614,  615,  616,  617,  618,  629,  629,
      619,  621,  622,  623,  624,  613,  625,  626,  614,  627,
      628,  615,  616,  617,  618,  619,  621,  622,  623,  630,
      631,  624,  643,  625,  626,  628,  627,  642,  630,  644,
      642,  647,  648,  649,  650,  653,  655,  656,  722,  631,
      661,  657,  658,  643,  720,  662,  647,  648,  649,  650,

      662,  655,  656,  644,  661,  653,  657,  658,  660,  672,
      673,  660,  674,  679,  684,  685,  685,  697,  686,  673,
      695,  696,  697,  698,  700,  699,  672,  679,  674,  701,
      701,  684,  686,  713,  716,  695,  711,  716,  713,  696,
      699,  715,  698,  700,  725,  711,  715,  726,  727,  728,
      736,  726,  739,  737,  738,  738,  744,  752,  745,  725,
      745,  719,  727,  759,  736,  737,  728,  739,  746,  751,
      744,  746,  750,  750,  752,  755,  756,  757,  755,  751,
      759,  756,  760,  762,  763,  760,  765,  766,  766,  768,
      767,  718,  757,  767,  769,  714,  712,  710,  762,  709,

      765,  708,  707,  763,  705,  704,  768,  703,  702,  769,
      772,  772,  772,  694,  772,  772,  772,  772,  772,  772,
      773,  773,  693,  773,  774,  774,  692,  774,  775,  775,
      691,  690,  689,  775,  776,  776,  776,  776,  776,  776,
      776,  776,  776,  776,  777,  777,  688,  777,  777,  777,
      777,  777,  777,  777,  778,  778,  687,  683,  778,  778,
      682,  681,  778,  779,  779,  680,  779,  779,  779,  779,
      779,  779,  779,  780,  780,  678,  780,  781,  781,  677,
      781,  781,  781,  781,  781,  781,  781,  782,  782,  782,
      782,  782,  782,  782,  782,  782,  782,  783,  783,  676,

      783,  783,  783,  675,  783,  784,  784,  784,  784,  784,
      784,  784,  784,  784,  784,  785,  785,  671,  785,  785,
      785,  785,  785,  785,  785,  786,  786,  670,  669,  786,
      786,  786,  786,  787,  787,  668,  787,  787,  787,  787,
      787,  787,  787,  788,  788,  788,  788,  788,  788,  788,
      788,  788,  788,  789,  789,  666,  789,  789,  789,  789,
      789,  789,  789,  790,  790,  665,  790,  790,  790,  790,
      790,  790,  790,  791,  791,  664,  791,  791,  791,  791,
      791,  791,  791,  792,  792,  663,  792,  792,  792,  792,
      792,  792,  792,  793,  793,  659,  793,  793,  793,  793,

      793,  793,  793,  794,  794,  654,  794,  794,  794,  794,
      794,  794,  794,  795,  795,  652,  795,  795,  795,  795,
      795,  795,  795,  796,  796,  651,  796,  796,  796,  796,
      796,  796,  796,  797,  797,  646,  797,  797,  797,  797,
      797,  797,  797,  798,  798,  645,  798,  798,  798,  798,
      798,  798,  798,  640,  639,  638,  637,  635,  634,  633,
      632,  620,  608,  607,  606,  605,  604,  603,  602,  601,
      600,  578,  577,  576,  575,  574,  573,  572,  571,  570,
      569,  568,  567,  563,  562,  539,  538,  537,  536,  535,
      534,  530,  529,  528,  502,  500,  499,  496,  491,  490,

      489,  488,  486,  479,  468,  467,  466,  465,  459,  449,
      447,  442,  438,  436,  435,  434,  433,  431,  430,  429,
      428,  426,  403,  402,  401,  399,  397,  392,  391,  390,
      388,  387,  369,  361,  358,  356,  350,  346,  345,  343,
      342,  341,  314,  312,  311,  310,  308,  306,  304,  301,
      299,  298,  296,  295,  294,  293,  292,  291,  290,  289,
      265,  260,  258,  255,  254,  253,  250,  249,  248,  246,
      245,  240,  239,  238,  237,  236,  235,  234,  233,  216,
      212,  206,  205,  202,  201,  200,  199,  192,  191,  190,
      189,  188,  187,  157,  156,  154,  152,  145,  144,  142,

      128,  108,  107,  102,   73,   67,   66,   38,   36,   32,
       30,   11,    3,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771,  771,  771,  771,
      771,  771,  771,  771,  771,  771,  771
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[95] =
    {   0,
0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "vtkParse.l"
#line 3 "vtkParse.l"

/*

This file must be translated to C and modified to build everywhere.

Run flex like this:

  flex -olex.yy.c vtkParse.l

Modify lex.yy.c:
  - remove yyunput function
  - remove TABs
  - change yy_n_chars declarations from "int yy_n_chars;" to
    "size_t yy_n_chars;" in both the yy_buffer_state structure
    and the global scope.
  - change num_to_read declaration from "int num_to_read;" to
    "size_t num_to_read;" in yy_get_next_buffer function.

*/

/* We do not care of interactive mode */
#define YY_NEVER_INTERACTIVE 1
#define YY_NO_UNPUT 1

/* Do not include unistd.h in generated source. */
#define YY_NO_UNISTD_H

/* Skip declaring this function.  It is a macro.  */
#define YY_SKIP_YYWRAP

#ifdef _WIN32
#pragma warning ( disable : 4018 )
#pragma warning ( disable : 4127 )
#pragma warning ( disable : 4131 )
#pragma warning ( disable : 4244 )
#pragma warning ( disable : 4251 )
#pragma warning ( disable : 4267 )
#pragma warning ( disable : 4305 )
#pragma warning ( disable : 4309 )
#pragma warning ( disable : 4706 )
#pragma warning ( disable : 4786 )
#endif

#line 1179 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
  if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
    { \
    int c = '*'; \
    size_t n; \
    for ( n = 0; n < max_size && \
           (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
      buf[n] = (char) c; \
    if ( c == '\n' ) \
      buf[n++] = (char) c; \
    if ( c == EOF && ferror( yyin ) ) \
      YY_FATAL_ERROR( "input in flex scanner failed" ); \
    result = n; \
    } \
  else \
    { \
    errno=0; \
    while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
      { \
      if( errno != EINTR) \
        { \
        YY_FATAL_ERROR( "input in flex scanner failed" ); \
        break; \
        } \
      errno=0; \
      clearerr(yyin); \
      } \
    }\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
  if ( yyleng > 0 ) \
    YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
        (yytext[yyleng - 1] == '\n'); \
  YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
  register yy_state_type yy_current_state;
  register char *yy_cp, *yy_bp;
  register int yy_act;
    
#line 49 "vtkParse.l"


#line 1372 "lex.yy.c"

  if ( !(yy_init) )
    {
    (yy_init) = 1;

#ifdef YY_USER_INIT
    YY_USER_INIT;
#endif

    if ( ! (yy_start) )
      (yy_start) = 1;  /* first start state */

    if ( ! yyin )
      yyin = stdin;

    if ( ! yyout )
      yyout = stdout;

    if ( ! YY_CURRENT_BUFFER ) {
      yyensure_buffer_stack ();
      YY_CURRENT_BUFFER_LVALUE =
        yy_create_buffer(yyin,YY_BUF_SIZE );
    }

    yy_load_buffer_state( );
    }

  while ( 1 )    /* loops until end-of-file is reached */
    {
    yy_cp = (yy_c_buf_p);

    /* Support of yytext. */
    *yy_cp = (yy_hold_char);

    /* yy_bp points to the position in yy_ch_buf of the start of
     * the current run.
     */
    yy_bp = yy_cp;

    yy_current_state = (yy_start);
    yy_current_state += YY_AT_BOL();
yy_match:
    do
      {
      register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
      if ( yy_accept[yy_current_state] )
        {
        (yy_last_accepting_state) = yy_current_state;
        (yy_last_accepting_cpos) = yy_cp;
        }
      while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
        {
        yy_current_state = (int) yy_def[yy_current_state];
        if ( yy_current_state >= 772 )
          yy_c = yy_meta[(unsigned int) yy_c];
        }
      yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
      ++yy_cp;
      }
    while ( yy_base[yy_current_state] != 1714 );

yy_find_action:
    yy_act = yy_accept[yy_current_state];
    if ( yy_act == 0 )
      { /* have to back up */
      yy_cp = (yy_last_accepting_cpos);
      yy_current_state = (yy_last_accepting_state);
      yy_act = yy_accept[yy_current_state];
      }

    YY_DO_BEFORE_ACTION;

    if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
      {
      int yyl;
      for ( yyl = 0; yyl < yyleng; ++yyl )
        if ( yytext[yyl] == '\n' )
             
    yylineno++;
;
      }

do_action:  /* This label is used only to access EOF actions. */

    switch ( yy_act )
  { /* beginning of action switch */
      case 0: /* must back up */
      /* undo the effects of YY_DO_BEFORE_ACTION */
      *yy_cp = (yy_hold_char);
      yy_cp = (yy_last_accepting_cpos);
      yy_current_state = (yy_last_accepting_state);
      goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 51 "vtkParse.l"
{ int c1 = 0, c2 = input();
       for (;;)
   {
         if (c2 == 0) 
           {
           fprintf(yyout,"Cannot find closing comment.\n");
           break;
           }
         if (c1 == '*' && c2 == '/') break;
         c1 = c2; c2 = input();
         }
     };
  YY_BREAK
case 2:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 64 "vtkParse.l"
{ 
       int c1 = 0, c2 = 0, c3 = 0, c4 = 0, c5 = input();
       for (;;)
   {
         if (c5 == 0) 
           {
           fprintf(yyout,"Cannot find matching //ETX.\n");
           break;
           }
         if (c1 == '/' && c2 == '/' && c3 == 'E' && c4 == 'T' && c5 == 'X') break;
         c1 = c2; c2 = c3; c3 = c4; c4 = c5; c5 = input();
         }
       for (;;)
         {
         if (c5 == 0) break;
         if (c5 == '\n') break;
         c5 = input();
         } 
     };
  YY_BREAK
case 3:
YY_RULE_SETUP
#line 84 "vtkParse.l"
{ 
     int pos = 1;
     while (yytext[pos-1] != 'M' || yytext[pos] != 'E')
       {
       pos++; 
       }
     yylval.str = (char *)malloc(yyleng + 1 - pos - 1);
     memcpy(yylval.str,yytext+ pos + 1,yyleng - pos - 1);
     yylval.str[yyleng - pos - 1] = '\0';
     data.NameComment = vtkstrdup(yylval.str);
     };
  YY_BREAK
case 4:
YY_RULE_SETUP
#line 96 "vtkParse.l"
{ 
     CommentState = 1;
     data.Description = (char*)malloc(100000);
     data.Description[0] = '\0';
     };
  YY_BREAK
case 5:
YY_RULE_SETUP
#line 102 "vtkParse.l"
{ 
     CommentState = 3;
     data.SeeAlso = (char*)malloc(100000);
     data.SeeAlso[0] = '\0';
     };
  YY_BREAK
case 6:
YY_RULE_SETUP
#line 108 "vtkParse.l"
{ 
     CommentState = 3;
     data.SeeAlso = (char*)malloc(100000);
     data.SeeAlso[0] = '\0';
     };
  YY_BREAK
case 7:
YY_RULE_SETUP
#line 114 "vtkParse.l"
{ 
     CommentState = 4;
     data.Caveats = (char*)malloc(100000);
     data.Caveats[0] = '\0';
     };
  YY_BREAK
case 8:
YY_RULE_SETUP
#line 120 "vtkParse.l"
{ 
     CommentState = 2;
     HaveComment = 1;
     CommentText[0] = '\0';
     };
  YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 126 "vtkParse.l"
{ 
     HaveComment = 0; 
     CommentState = 0; 
     };
  YY_BREAK
case 10:
YY_RULE_SETUP
#line 131 "vtkParse.l"
{ 
     int pos = 1;
     while (yytext[pos-1] != '/' || yytext[pos] != '/') pos++; 
     yylval.str = (char *)malloc(yyleng + 1 - pos - 1 + 1);
     memcpy(yylval.str,yytext+ pos + 1,yyleng - pos - 1);
     yylval.str[yyleng - pos - 1] = '\n';
     yylval.str[yyleng - pos] = '\0';
     switch (CommentState)
       {
       case 1: strcat(data.Description,yylval.str); break;
       case 2: strcat(CommentText,yylval.str); break;
       case 3: strcat(data.SeeAlso,yylval.str); break;
       case 4: strcat(data.Caveats,yylval.str); break;
       }
     };
  YY_BREAK
case 11:
YY_RULE_SETUP
#line 147 "vtkParse.l"
;
  YY_BREAK
case 12:
YY_RULE_SETUP
#line 149 "vtkParse.l"
;
  YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 151 "vtkParse.l"
;
  YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 153 "vtkParse.l"
{
   sscanf(yytext+1,"%d",&yylval.integer); return(ARRAY_NUM);}
  YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 157 "vtkParse.l"
return(CLASS_REF);
  YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 159 "vtkParse.l"
return(VAR_FUNCTION);
  YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 161 "vtkParse.l"
return(SHORT);
  YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 162 "vtkParse.l"
return(LONG);
  YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 163 "vtkParse.l"
return(SHORT);
  YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 164 "vtkParse.l"
return(LONG);
  YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 166 "vtkParse.l"
return(LONG_LONG);
  YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 167 "vtkParse.l"
return(LONG_LONG);
  YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 168 "vtkParse.l"
return(LONG_LONG);
  YY_BREAK
case 24:
YY_RULE_SETUP
#line 170 "vtkParse.l"
return(INT64__);
  YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 172 "vtkParse.l"
return(SIGNED_CHAR);
  YY_BREAK
case 26:
YY_RULE_SETUP
#line 174 "vtkParse.l"
return(CLASS);
  YY_BREAK
case 27:
YY_RULE_SETUP
#line 175 "vtkParse.l"
return(PUBLIC);
  YY_BREAK
case 28:
YY_RULE_SETUP
#line 176 "vtkParse.l"
return(PRIVATE);
  YY_BREAK
case 29:
YY_RULE_SETUP
#line 177 "vtkParse.l"
return(PROTECTED);
  YY_BREAK
case 30:
YY_RULE_SETUP
#line 178 "vtkParse.l"
return(INT);
  YY_BREAK
case 31:
YY_RULE_SETUP
#line 179 "vtkParse.l"
return(FLOAT);
  YY_BREAK
case 32:
YY_RULE_SETUP
#line 180 "vtkParse.l"
return(SHORT);
  YY_BREAK
case 33:
YY_RULE_SETUP
#line 181 "vtkParse.l"
return(LONG);
  YY_BREAK
case 34:
YY_RULE_SETUP
#line 182 "vtkParse.l"
return(DOUBLE);
  YY_BREAK
case 35:
YY_RULE_SETUP
#line 183 "vtkParse.l"
return(VOID);
  YY_BREAK
case 36:
YY_RULE_SETUP
#line 184 "vtkParse.l"
return(CHAR);
  YY_BREAK
case 37:
YY_RULE_SETUP
#line 185 "vtkParse.l"
return(BOOL);
  YY_BREAK
case 38:
YY_RULE_SETUP
#line 186 "vtkParse.l"
return(VIRTUAL);
  YY_BREAK
case 39:
YY_RULE_SETUP
#line 187 "vtkParse.l"
return(CONST);
  YY_BREAK
case 40:
YY_RULE_SETUP
#line 188 "vtkParse.l"
return(OPERATOR);
  YY_BREAK
case 41:
YY_RULE_SETUP
#line 189 "vtkParse.l"
return(UNSIGNED);
  YY_BREAK
case 42:
YY_RULE_SETUP
#line 190 "vtkParse.l"
return(FRIEND);
  YY_BREAK
case 43:
YY_RULE_SETUP
#line 191 "vtkParse.l"
return(STATIC);
  YY_BREAK
case 44:
YY_RULE_SETUP
#line 193 "vtkParse.l"
return(DOUBLE);
  YY_BREAK
case 45:
YY_RULE_SETUP
#line 194 "vtkParse.l"
return(IdType);
  YY_BREAK
case 46:
YY_RULE_SETUP
#line 195 "vtkParse.l"
return(StdString);
  YY_BREAK
case 47:
YY_RULE_SETUP
#line 196 "vtkParse.l"
return(SetMacro);
  YY_BREAK
case 48:
YY_RULE_SETUP
#line 197 "vtkParse.l"
return(GetMacro);
  YY_BREAK
case 49:
YY_RULE_SETUP
#line 198 "vtkParse.l"
return(SetStringMacro);
  YY_BREAK
case 50:
YY_RULE_SETUP
#line 199 "vtkParse.l"
return(GetStringMacro);
  YY_BREAK
case 51:
YY_RULE_SETUP
#line 200 "vtkParse.l"
return(SetClampMacro);
  YY_BREAK
case 52:
YY_RULE_SETUP
#line 201 "vtkParse.l"
return(SetObjectMacro);
  YY_BREAK
case 53:
YY_RULE_SETUP
#line 202 "vtkParse.l"
return(SetReferenceCountedObjectMacro);
  YY_BREAK
case 54:
YY_RULE_SETUP
#line 203 "vtkParse.l"
return(GetObjectMacro);
  YY_BREAK
case 55:
YY_RULE_SETUP
#line 204 "vtkParse.l"
return(BooleanMacro);
  YY_BREAK
case 56:
YY_RULE_SETUP
#line 205 "vtkParse.l"
return(SetVector2Macro);
  YY_BREAK
case 57:
YY_RULE_SETUP
#line 206 "vtkParse.l"
return(SetVector3Macro);
  YY_BREAK
case 58:
YY_RULE_SETUP
#line 207 "vtkParse.l"
return(SetVector4Macro);
  YY_BREAK
case 59:
YY_RULE_SETUP
#line 208 "vtkParse.l"
return(SetVector6Macro);
  YY_BREAK
case 60:
YY_RULE_SETUP
#line 209 "vtkParse.l"
return(GetVector2Macro);
  YY_BREAK
case 61:
YY_RULE_SETUP
#line 210 "vtkParse.l"
return(GetVector3Macro);
  YY_BREAK
case 62:
YY_RULE_SETUP
#line 211 "vtkParse.l"
return(GetVector4Macro);
  YY_BREAK
case 63:
YY_RULE_SETUP
#line 212 "vtkParse.l"
return(GetVector6Macro);
  YY_BREAK
case 64:
YY_RULE_SETUP
#line 213 "vtkParse.l"
return(SetVectorMacro);
  YY_BREAK
case 65:
YY_RULE_SETUP
#line 214 "vtkParse.l"
return(GetVectorMacro);
  YY_BREAK
case 66:
YY_RULE_SETUP
#line 215 "vtkParse.l"
return(ViewportCoordinateMacro);
  YY_BREAK
case 67:
YY_RULE_SETUP
#line 216 "vtkParse.l"
return(WorldCoordinateMacro);
  YY_BREAK
case 68:
YY_RULE_SETUP
#line 217 "vtkParse.l"
return(TypeMacro);
  YY_BREAK
case 69:
YY_RULE_SETUP
#line 218 "vtkParse.l"
return(TypeMacro);
  YY_BREAK
case 70:
YY_RULE_SETUP
#line 219 "vtkParse.l"
return(TypeMacro);
  YY_BREAK
case 71:
YY_RULE_SETUP
#line 220 "vtkParse.l"
return(TypeMacro);
  YY_BREAK
case 72:
YY_RULE_SETUP
#line 221 "vtkParse.l"
return(VTK_LEGACY);
  YY_BREAK
case 73:
YY_RULE_SETUP
#line 222 "vtkParse.l"
return(VTK_WRAP_EXTERN);
  YY_BREAK
case 74:
YY_RULE_SETUP
#line 223 "vtkParse.l"
return(TypeInt8);
  YY_BREAK
case 75:
YY_RULE_SETUP
#line 224 "vtkParse.l"
return(TypeUInt8);
  YY_BREAK
case 76:
YY_RULE_SETUP
#line 225 "vtkParse.l"
return(TypeInt16);
  YY_BREAK
case 77:
YY_RULE_SETUP
#line 226 "vtkParse.l"
return(TypeUInt16);
  YY_BREAK
case 78:
YY_RULE_SETUP
#line 227 "vtkParse.l"
return(TypeInt32);
  YY_BREAK
case 79:
YY_RULE_SETUP
#line 228 "vtkParse.l"
return(TypeUInt32);
  YY_BREAK
case 80:
YY_RULE_SETUP
#line 229 "vtkParse.l"
return(TypeInt64);
  YY_BREAK
case 81:
YY_RULE_SETUP
#line 230 "vtkParse.l"
return(TypeUInt64);
  YY_BREAK
case 82:
YY_RULE_SETUP
#line 231 "vtkParse.l"
return(TypeFloat32);
  YY_BREAK
case 83:
YY_RULE_SETUP
#line 232 "vtkParse.l"
return(TypeFloat64);
  YY_BREAK
case 84:
YY_RULE_SETUP
#line 235 "vtkParse.l"
{ sscanf(yytext,"%d",&yylval.integer); return(NUM);}
  YY_BREAK
case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
#line 237 "vtkParse.l"
{
    yylval.str =  vtkstrdup(yytext + 1);
    yylval.str[strlen(yytext)-2] = '\0';
    return(STRING);
    }
  YY_BREAK
case 86:
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up yytext again */
YY_RULE_SETUP
#line 243 "vtkParse.l"
;
  YY_BREAK
case 87:
YY_RULE_SETUP
#line 246 "vtkParse.l"
{ yylval.str = (char *)malloc(yyleng + 1);
                     memcpy(yylval.str,yytext,yyleng);
                     yylval.str[yyleng] = '\0';
                     return(VTK_ID);
                    }
  YY_BREAK
case 88:
YY_RULE_SETUP
#line 252 "vtkParse.l"
{ yylval.str = (char *)malloc(yyleng + 1);
                          memcpy(yylval.str,yytext,yyleng);
                          yylval.str[yyleng] = '\0';
                          return(ID);
                        }
  YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 258 "vtkParse.l"
;
  YY_BREAK
case 90:
YY_RULE_SETUP
#line 261 "vtkParse.l"
return(yytext[0]);
  YY_BREAK
case 91:
YY_RULE_SETUP
#line 262 "vtkParse.l"
return(yytext[0]);
  YY_BREAK
case 92:
YY_RULE_SETUP
#line 265 "vtkParse.l"
{  return(yytext[0]); }
  YY_BREAK
case 93:
YY_RULE_SETUP
#line 267 "vtkParse.l"
return(OTHER);
  YY_BREAK
case 94:
YY_RULE_SETUP
#line 268 "vtkParse.l"
ECHO;
  YY_BREAK
#line 2046 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
  yyterminate();

  case YY_END_OF_BUFFER:
    {
    /* Amount of text matched not including the EOB char. */
    int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

    /* Undo the effects of YY_DO_BEFORE_ACTION. */
    *yy_cp = (yy_hold_char);
    YY_RESTORE_YY_MORE_OFFSET

    if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
      {
      /* We're scanning a new file or input source.  It's
       * possible that this happened because the user
       * just pointed yyin at a new source and called
       * yylex().  If so, then we have to assure
       * consistency between YY_CURRENT_BUFFER and our
       * globals.  Here is the right place to do so, because
       * this is the first action (other than possibly a
       * back-up) that will match for the new input source.
       */
      (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
      YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
      YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
      }

    /* Note that here we test for yy_c_buf_p "<=" to the position
     * of the first EOB in the buffer, since yy_c_buf_p will
     * already have been incremented past the NUL character
     * (since all states make transitions on EOB to the
     * end-of-buffer state).  Contrast this with the test
     * in input().
     */
    if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
      { /* This was really a NUL. */
      yy_state_type yy_next_state;

      (yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

      yy_current_state = yy_get_previous_state(  );

      /* Okay, we're now positioned to make the NUL
       * transition.  We couldn't have
       * yy_get_previous_state() go ahead and do it
       * for us because it doesn't know how to deal
       * with the possibility of jamming (and we don't
       * want to build jamming into it because then it
       * will run more slowly).
       */

      yy_next_state = yy_try_NUL_trans( yy_current_state );

      yy_bp = (yytext_ptr) + YY_MORE_ADJ;

      if ( yy_next_state )
        {
        /* Consume the NUL. */
        yy_cp = ++(yy_c_buf_p);
        yy_current_state = yy_next_state;
        goto yy_match;
        }

      else
        {
        yy_cp = (yy_c_buf_p);
        goto yy_find_action;
        }
      }

    else switch ( yy_get_next_buffer(  ) )
      {
      case EOB_ACT_END_OF_FILE:
        {
        (yy_did_buffer_switch_on_eof) = 0;

        if ( yywrap( ) )
          {
          /* Note: because we've taken care in
           * yy_get_next_buffer() to have set up
           * yytext, we can now set up
           * yy_c_buf_p so that if some total
           * hoser (like flex itself) wants to
           * call the scanner after we return the
           * YY_NULL, it'll still work - another
           * YY_NULL will get returned.
           */
          (yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

          yy_act = YY_STATE_EOF(YY_START);
          goto do_action;
          }

        else
          {
          if ( ! (yy_did_buffer_switch_on_eof) )
            YY_NEW_FILE;
          }
        break;
        }

      case EOB_ACT_CONTINUE_SCAN:
        (yy_c_buf_p) =
          (yytext_ptr) + yy_amount_of_matched_text;

        yy_current_state = yy_get_previous_state(  );

        yy_cp = (yy_c_buf_p);
        yy_bp = (yytext_ptr) + YY_MORE_ADJ;
        goto yy_match;

      case EOB_ACT_LAST_MATCH:
        (yy_c_buf_p) =
        &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

        yy_current_state = yy_get_previous_state(  );

        yy_cp = (yy_c_buf_p);
        yy_bp = (yytext_ptr) + YY_MORE_ADJ;
        goto yy_find_action;
      }
    break;
    }

  default:
    YY_FATAL_ERROR(
      "fatal flex scanner internal error--no action found" );
  } /* end of action switch */
    } /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *  EOB_ACT_LAST_MATCH -
 *  EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *  EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
      register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
  register char *source = (yytext_ptr);
  register int number_to_move, i;
  int ret_val;

  if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
    YY_FATAL_ERROR(
    "fatal flex scanner internal error--end of buffer missed" );

  if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
    { /* Don't try to fill the buffer, so this is an EOF. */
    if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
      {
      /* We matched a single character, the EOB, so
       * treat this as a final EOF.
       */
      return EOB_ACT_END_OF_FILE;
      }

    else
      {
      /* We matched some text prior to the EOB, first
       * process it.
       */
      return EOB_ACT_LAST_MATCH;
      }
    }

  /* Try to read more data. */

  /* First move last chars to start of buffer. */
  number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

  for ( i = 0; i < number_to_move; ++i )
    *(dest++) = *(source++);

  if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
    /* don't do the read, it's not guaranteed to return an EOF,
     * just force an EOF
     */
    YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

  else
    {
      size_t num_to_read =
      YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

    while ( num_to_read <= 0 )
      { /* Not enough room in the buffer - grow it. */

      /* just a shorter name for the current buffer */
      YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

      int yy_c_buf_p_offset =
        (int) ((yy_c_buf_p) - b->yy_ch_buf);

      if ( b->yy_is_our_buffer )
        {
        int new_size = b->yy_buf_size * 2;

        if ( new_size <= 0 )
          b->yy_buf_size += b->yy_buf_size / 8;
        else
          b->yy_buf_size *= 2;

        b->yy_ch_buf = (char *)
          /* Include room in for 2 EOB chars. */
          yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
        }
      else
        /* Can't grow it, we don't own it. */
        b->yy_ch_buf = 0;

      if ( ! b->yy_ch_buf )
        YY_FATAL_ERROR(
        "fatal error - scanner input buffer overflow" );

      (yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

      num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
            number_to_move - 1;

      }

    if ( num_to_read > YY_READ_BUF_SIZE )
      num_to_read = YY_READ_BUF_SIZE;

    /* Read in more data. */
    YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
      (yy_n_chars), (size_t) num_to_read );

    YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
    }

  if ( (yy_n_chars) == 0 )
    {
    if ( number_to_move == YY_MORE_ADJ )
      {
      ret_val = EOB_ACT_END_OF_FILE;
      yyrestart(yyin  );
      }

    else
      {
      ret_val = EOB_ACT_LAST_MATCH;
      YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
        YY_BUFFER_EOF_PENDING;
      }
    }

  else
    ret_val = EOB_ACT_CONTINUE_SCAN;

  if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
    /* Extend the array by 50%, plus the number we really need. */
    yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
    YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
    if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
      YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
  }

  (yy_n_chars) += number_to_move;
  YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
  YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

  (yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

  return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
  register yy_state_type yy_current_state;
  register char *yy_cp;
    
  yy_current_state = (yy_start);
  yy_current_state += YY_AT_BOL();

  for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
    {
    register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
    if ( yy_accept[yy_current_state] )
      {
      (yy_last_accepting_state) = yy_current_state;
      (yy_last_accepting_cpos) = yy_cp;
      }
    while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
      {
      yy_current_state = (int) yy_def[yy_current_state];
      if ( yy_current_state >= 772 )
        yy_c = yy_meta[(unsigned int) yy_c];
      }
    yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
    }

  return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *  next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
  register int yy_is_jam;
      register char *yy_cp = (yy_c_buf_p);

  register YY_CHAR yy_c = 1;
  if ( yy_accept[yy_current_state] )
    {
    (yy_last_accepting_state) = yy_current_state;
    (yy_last_accepting_cpos) = yy_cp;
    }
  while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
    {
    yy_current_state = (int) yy_def[yy_current_state];
    if ( yy_current_state >= 772 )
      yy_c = yy_meta[(unsigned int) yy_c];
    }
  yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
  yy_is_jam = (yy_current_state == 771);

  return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
  int c;
    
  *(yy_c_buf_p) = (yy_hold_char);

  if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
    {
    /* yy_c_buf_p now points to the character we want to return.
     * If this occurs *before* the EOB characters, then it's a
     * valid NUL; if not, then we've hit the end of the buffer.
     */
    if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
      /* This was really a NUL. */
      *(yy_c_buf_p) = '\0';

    else
      { /* need more input */
      int offset = (yy_c_buf_p) - (yytext_ptr);
      ++(yy_c_buf_p);

      switch ( yy_get_next_buffer(  ) )
        {
        case EOB_ACT_LAST_MATCH:
          /* This happens because yy_g_n_b()
           * sees that we've accumulated a
           * token and flags that we need to
           * try matching the token before
           * proceeding.  But for input(),
           * there's no matching to consider.
           * So convert the EOB_ACT_LAST_MATCH
           * to EOB_ACT_END_OF_FILE.
           */

          /* Reset buffer status. */
          yyrestart(yyin );

          /*FALLTHROUGH*/

        case EOB_ACT_END_OF_FILE:
          {
          if ( yywrap( ) )
            return EOF;

          if ( ! (yy_did_buffer_switch_on_eof) )
            YY_NEW_FILE;
#ifdef __cplusplus
          return yyinput();
#else
          return input();
#endif
          }

        case EOB_ACT_CONTINUE_SCAN:
          (yy_c_buf_p) = (yytext_ptr) + offset;
          break;
        }
      }
    }

  c = *(unsigned char *) (yy_c_buf_p);  /* cast for 8-bit char's */
  *(yy_c_buf_p) = '\0';  /* preserve yytext */
  (yy_hold_char) = *++(yy_c_buf_p);

  YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');
  if ( YY_CURRENT_BUFFER_LVALUE->yy_at_bol )
       
    yylineno++;
;

  return c;
}
#endif  /* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
  if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
    YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
  }

  yy_init_buffer(YY_CURRENT_BUFFER,input_file );
  yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
  /* TODO. We should be able to replace this entire function body
   * with
   *    yypop_buffer_state();
   *    yypush_buffer_state(new_buffer);
     */
  yyensure_buffer_stack ();
  if ( YY_CURRENT_BUFFER == new_buffer )
    return;

  if ( YY_CURRENT_BUFFER )
    {
    /* Flush out information for old buffer. */
    *(yy_c_buf_p) = (yy_hold_char);
    YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
    YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
    }

  YY_CURRENT_BUFFER_LVALUE = new_buffer;
  yy_load_buffer_state( );

  /* We don't actually know whether we did this switch during
   * EOF (yywrap()) processing, but the only time this flag
   * is looked at is after yywrap() is called, so it's safe
   * to go ahead and always set it.
   */
  (yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
      (yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
  (yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
  yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
  (yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
  YY_BUFFER_STATE b;
    
  b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
  if ( ! b )
    YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

  b->yy_buf_size = size;

  /* yy_ch_buf has to be 2 characters longer than the size given because
   * we need to put in 2 end-of-buffer characters.
   */
  b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
  if ( ! b->yy_ch_buf )
    YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

  b->yy_is_our_buffer = 1;

  yy_init_buffer(b,file );

  return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
  if ( ! b )
    return;

  if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
    YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

  if ( b->yy_is_our_buffer )
    yyfree((void *) b->yy_ch_buf  );

  yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
  int oerrno = errno;
    
  yy_flush_buffer(b );

  b->yy_input_file = file;
  b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
  errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
      if ( ! b )
    return;

  b->yy_n_chars = 0;

  /* We always need two end-of-buffer characters.  The first causes
   * a transition to the end-of-buffer state.  The second causes
   * a jam in that state.
   */
  b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
  b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

  b->yy_buf_pos = &b->yy_ch_buf[0];

  b->yy_at_bol = 1;
  b->yy_buffer_status = YY_BUFFER_NEW;

  if ( b == YY_CURRENT_BUFFER )
    yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
      if (new_buffer == NULL)
    return;

  yyensure_buffer_stack();

  /* This block is copied from yy_switch_to_buffer. */
  if ( YY_CURRENT_BUFFER )
    {
    /* Flush out information for old buffer. */
    *(yy_c_buf_p) = (yy_hold_char);
    YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
    YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
    }

  /* Only push if top exists. Otherwise, replace top. */
  if (YY_CURRENT_BUFFER)
    (yy_buffer_stack_top)++;
  YY_CURRENT_BUFFER_LVALUE = new_buffer;

  /* copied from yy_switch_to_buffer. */
  yy_load_buffer_state( );
  (yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
      if (!YY_CURRENT_BUFFER)
    return;

  yy_delete_buffer(YY_CURRENT_BUFFER );
  YY_CURRENT_BUFFER_LVALUE = NULL;
  if ((yy_buffer_stack_top) > 0)
    --(yy_buffer_stack_top);

  if (YY_CURRENT_BUFFER) {
    yy_load_buffer_state( );
    (yy_did_buffer_switch_on_eof) = 1;
  }
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
  int num_to_alloc;
    
  if (!(yy_buffer_stack)) {

    /* First allocation is just for 2 elements, since we don't know if this
     * scanner will even need a stack. We use 2 instead of 1 to avoid an
     * immediate realloc on the next call.
         */
    num_to_alloc = 1;
    (yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
                (num_to_alloc * sizeof(struct yy_buffer_state*)
                );
    if ( ! (yy_buffer_stack) )
      YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
                  
    memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
        
    (yy_buffer_stack_max) = num_to_alloc;
    (yy_buffer_stack_top) = 0;
    return;
  }

  if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

    /* Increase the buffer to prepare for a possible push. */
    int grow_size = 8 /* arbitrary grow size */;

    num_to_alloc = (yy_buffer_stack_max) + grow_size;
    (yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
                ((yy_buffer_stack),
                num_to_alloc * sizeof(struct yy_buffer_state*)
                );
    if ( ! (yy_buffer_stack) )
      YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

    /* zero only the new slots.*/
    memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
    (yy_buffer_stack_max) = num_to_alloc;
  }
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
  YY_BUFFER_STATE b;
    
  if ( size < 2 ||
       base[size-2] != YY_END_OF_BUFFER_CHAR ||
       base[size-1] != YY_END_OF_BUFFER_CHAR )
    /* They forgot to leave room for the EOB's. */
    return 0;

  b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
  if ( ! b )
    YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

  b->yy_buf_size = size - 2;  /* "- 2" to take care of EOB's */
  b->yy_buf_pos = b->yy_ch_buf = base;
  b->yy_is_our_buffer = 0;
  b->yy_input_file = 0;
  b->yy_n_chars = b->yy_buf_size;
  b->yy_is_interactive = 0;
  b->yy_at_bol = 1;
  b->yy_fill_buffer = 0;
  b->yy_buffer_status = YY_BUFFER_NEW;

  yy_switch_to_buffer(b  );

  return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
  return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
  YY_BUFFER_STATE b;
  char *buf;
  yy_size_t n;
  int i;
    
  /* Get memory for full buffer, including space for trailing EOB's. */
  n = _yybytes_len + 2;
  buf = (char *) yyalloc(n  );
  if ( ! buf )
    YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

  for ( i = 0; i < _yybytes_len; ++i )
    buf[i] = yybytes[i];

  buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

  b = yy_scan_buffer(buf,n );
  if ( ! b )
    YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

  /* It's okay to grow etc. this buffer, and we should throw it
   * away when we're done.
   */
  b->yy_is_our_buffer = 1;

  return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
      (void) fprintf( stderr, "%s\n", msg );
  exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
  do \
    { \
    /* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
    yytext[yyleng] = (yy_hold_char); \
    (yy_c_buf_p) = yytext + yyless_macro_arg; \
    (yy_hold_char) = *(yy_c_buf_p); \
    *(yy_c_buf_p) = '\0'; \
    yyleng = yyless_macro_arg; \
    } \
  while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
  while(YY_CURRENT_BUFFER){
    yy_delete_buffer(YY_CURRENT_BUFFER  );
    YY_CURRENT_BUFFER_LVALUE = NULL;
    yypop_buffer_state();
  }

  /* Destroy the stack itself. */
  yyfree((yy_buffer_stack) );
  (yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
  register int i;
  for ( i = 0; i < n; ++i )
    s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
  register int n;
  for ( n = 0; s[n]; ++n )
    ;

  return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
  return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
  /* The cast to (char *) in the following accommodates both
   * implementations that use char* generic pointers, and those
   * that use void* generic pointers.  It works with the latter
   * because both ANSI C and C++ allow castless assignment from
   * any pointer type to void*, and deal with argument conversions
   * as though doing an assignment.
   */
  return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
  free( (char *) ptr );  /* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 268 "vtkParse.l"




